/**
 * @file        Redis数据库配置
 * @author      hotok
 * @date        2025-06-28
 * @lastEditor  hotok
 * @lastEditTime 2025-06-28
 * @description 读取环境变量并导出Redis连接配置
 */

/**
 * Redis数据库连接配置
 * @property {string} connectName - Redis连接名称
 * @property {string} host        - Redis服务器主机地址
 * @property {number} port        - Redis服务器端口号
 * @property {string} username    - Redis用户名
 * @property {string} password    - Redis密码
 * @property {number} database    - Redis数据库索引
 * @property {string} url         - Redis连接URL
 */
export const redisConfig = {
    /** Redis连接名称 */
    connectName: process.env.REDIS_CONNECT_NAME || 'cursor-init-redis',
    /** Redis服务器主机地址 */
    host: process.env.REDIS_HOST || '172.16.1.3',
    /** Redis服务器端口号 */
    port: Number(process.env.REDIS_PORT) || 6379,
    /** Redis用户名 */
    username: process.env.REDIS_USERNAME || 'default',
    /** Redis密码 */
    password: process.env.REDIS_PASSWORD || 'docker',
    /** Redis数据库索引 */
    database: Number(process.env.REDIS_DATABASE) || 0,
};

/**
 * 构建Redis连接URL
 * @returns Redis连接URL字符串
 */
export const getRedisUrl = (): string => {
    const { username, password, host, port, database } = redisConfig;
    if (username && password) {
        return `redis://${username}:${password}@${host}:${port}/${database}`;
    }
    return `redis://${host}:${port}/${database}`;
}; 