/**
 * @file        健康检查控制器
 * @author      hotok
 * @date        2025-06-28
 * @lastEditor  hotok
 * @lastEditTime 2025-06-28
 * @description 提供服务健康状态检查，包括数据库、Redis等依赖检查
 */

import { Elysia } from 'elysia';
import { healthService } from '@/modules/health/health.service';

/**
 * 健康检查控制器
 * 提供系统健康状态检查接口
 */
export const healthController = new Elysia()
    .get('/', async (ctx) => await healthService.getHealthStatus(ctx), {
        detail: {
            tags: ['健康检查'],
            summary: '获取系统健康状态',
            description: '检查系统及各依赖服务的健康状态，包括数据库、Redis等',
        },
    })
    .get('/detailed', async (ctx) => await healthService.getDetailedHealthStatus(ctx), {
        detail: {
            tags: ['健康检查'],
            summary: '获取详细健康状态',
            description: '获取系统详细健康状态，包括性能指标、资源使用情况等',
        },
    }); 