/**
 * 数据库配置类型
 */
export interface DbConfig {
    /** 数据库主机地址 */
    host: string;
    /** 数据库端口号 */
    port: number;
    /** 数据库用户名 */
    user: string;
    /** 数据库密码 */
    password: string;
    /** 数据库名称 */
    database: string;
}

/**
 * JWT配置类型
 */
export interface JwtConfig {
    /** JWT签名密钥 */
    secret: string;
    /** Token有效期 */
    exp: string;
}

/**
 * Redis配置类型
 */
export interface RedisConfig {
    /** Redis连接名称 */
    connectName: string;
    /** Redis服务器主机地址 */
    host: string;
    /** Redis服务器端口号 */
    port: number;
    /** Redis用户名 */
    username: string;
    /** Redis密码 */
    password: string;
    /** Redis数据库索引 */
    database: number;
}
/**
 * 日志配置接口
 * @interface LogConfig
 */
export interface LogConfigType {
    /** 日志文件目录 */
    directory: string;
    /** 是否输出到控制台 */
    console: boolean;
    /** 单个日志文件最大大小 */
    maxSize: string;
    /** 最大保留文件数 */
    maxFiles: string;
    /** 日志等级 */
    level: string;
}

/**
 * 全局配置类型，包含所有配置项
 */
export interface GlobalConfig {
    /** 数据库配置 */
    db: DbConfig;
    /** JWT配置 */
    jwt: JwtConfig;
    /** Redis配置 */
    redis: RedisConfig;
    /** 日志配置 */
    logger: LogConfigType;
    /** 当前环境 */
    env: string;
}
